@@ -29,11 +29,16 @@ extern struct collect_image_info tty_cinfo;
 extern struct collect_image_info tty_cdata;
 extern int prepare_shared_tty(void);
 
+struct mount_info;
+extern int devpts_restore(struct mount_info *pm);
+
 extern int tty_prep_fds(void);
 extern void tty_fini_fds(void);
 
 extern int tty_restore_ctl_terminal(struct file_desc *d, int fd);
 
+extern int devpts_check_bindmount(struct mount_info *m);
+
 #define OPT_SHELL_JOB	"shell-job"
 
 #endif /* __CR_TTY_H__ */
